package PAUSE::Packages::Module;
$PAUSE::Packages::Module::VERSION = '0.14';
use 5.10.0;
use Moo 1.004005;

has 'name'    => (is => 'ro');
has 'version' => (is => 'ro');

1;
